# Cereja

<div align="center">
 <img src="https://i.ibb.co/dp8rZ3F/cereja-logo.png">
</div>

*Cereja is a bundle of useful functions that I don't want to rewrite.*

How many times have you needed to rewrite that function or base class? Well, I thought then of joining all my lines of code, bit by bit, in one place.

Not well structured yet :( ... But you can help me !!!

## Getting Started

Do not be shy \0/ ... Clone the repository and submit a function or module you made or use some function you liked.

### Prerequisites

* [Python 3.6+](https://www.python.org/downloads/ "Download python")
* [Pip3](https://pip.pypa.io "Download Pip")

### Installing

**Install Cereja Package**
```
python3 -m pip install --user cereja
```
or for all users
```
python3 -m pip install cereja
```
> Note: If you are using Windows, you do not need to use python3, but make sure your python path settings are correct. 

### Cereja Example usage
[Jupyter Notebook on Colab](/docs/cereja_example.ipynb)
## License

This project is licensed under the GNU License - see the [LICENSE.md](LICENSE.md) file for details
